#ifndef _DIRAC_LIBDIRAC_COMMON_DIRAC_STDINT_H
#define _DIRAC_LIBDIRAC_COMMON_DIRAC_STDINT_H 1
#ifndef _GENERATED_STDINT_H
#define _GENERATED_STDINT_H "dirac 1.0.2"
#define _STDINT_HAVE_STDINT_H 1
#include <stdint.h>
#endif
#endif
